(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    124735,       3494]
NotebookOptionsPosition[    121162,       3363]
NotebookOutlinePosition[    121538,       3379]
CellTagsIndexPosition[    121495,       3376]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Introduction", "Section",
 CellChangeTimes->{{3.7377901678146253`*^9, 3.7377901730229235`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Text", "[", 
  "\"\<This notebook lists the definitions of the coefficients appearing in \
equation (2.1b) of the manuscript entitled 'Sliding instability of draining \
fluid films' authored by G. F. Dietze, J. R. Picardo, and R. Narayanan.\>\"", 
  "]"}]], "Input",
 CellChangeTimes->{{3.7377901756200714`*^9, 3.737790337221315*^9}, {
  3.7377903697921777`*^9, 3.7377904403992157`*^9}, {3.737790479020425*^9, 
  3.737790564541317*^9}, {3.737790664033007*^9, 3.7377906686642723`*^9}, {
  3.737792461262803*^9, 3.7377924618458366`*^9}, {3.7377937163565903`*^9, 
  3.7377937291663227`*^9}}],

Cell[BoxData[
 InterpretationBox[Cell[BoxData[
   FormBox["\<\"This notebook lists the definitions of the coefficients \
appearing in equation (2.1b) of the manuscript entitled 'Sliding instability \
of draining fluid films' authored by G. F. Dietze, J. R. Picardo, and R. \
Narayanan.\"\>", TextForm]], "InlineText"],
  Text["This notebook lists the definitions of the coefficients appearing in \
equation (2.1b) of the manuscript entitled 'Sliding instability of draining \
fluid films' authored by G. F. Dietze, J. R. Picardo, and R. Narayanan."]]], \
"Output",
 CellChangeTimes->{{3.737792480860924*^9, 3.737792482868039*^9}, 
   3.73779261070335*^9, 3.737793247853793*^9, 3.737793282005747*^9, 
   3.737793444429037*^9, 3.7377935695021906`*^9, 3.7377937302743864`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Density and viscosity ratios", "Section",
 CellChangeTimes->{{3.73779339604727*^9, 3.7377934085829864`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Pirho", "\[Equal]", 
  RowBox[{"rho2", "/", "rho1"}]}], "\[IndentingNewLine]", 
 RowBox[{"Pimu", "\[Equal]", 
  RowBox[{"mu2", "/", "mu1"}]}]}], "Input",
 CellChangeTimes->{{3.737793411373146*^9, 3.737793427923093*^9}}],

Cell[BoxData[
 RowBox[{"Pirho", "\[Equal]", 
  FractionBox["rho2", "rho1"]}]], "Output",
 CellChangeTimes->{{3.7377934283191156`*^9, 3.737793444518042*^9}, 
   3.7377935695921955`*^9}],

Cell[BoxData[
 RowBox[{"Pimu", "\[Equal]", 
  FractionBox["mu2", "mu1"]}]], "Output",
 CellChangeTimes->{{3.7377934283191156`*^9, 3.737793444518042*^9}, 
   3.737793569596196*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model coefficients for equation (2.1b)", "Section",
 CellChangeTimes->{{3.686455815321295*^9, 3.6864558182541*^9}, {
   3.737792406926695*^9, 3.7377924155111856`*^9}, 3.7377925401433144`*^9, {
   3.737793458606848*^9, 3.737793463287115*^9}}],

Cell[CellGroupData[{

Cell["S1 and S2", "Subsection",
 CellChangeTimes->{{3.7377915548949614`*^9, 3.737791557103088*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"S1def", "=", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"24", "*", 
           RowBox[{"H", "^", "4"}], "*", "Pirho"}], " ", "+", " ", 
          RowBox[{"16", "*", 
           RowBox[{"H", "^", "3"}], "*", 
           RowBox[{"(", 
            RowBox[{"4", " ", "-", " ", 
             RowBox[{"5", "*", "Pirho"}]}], ")"}], "*", "h"}], " ", "+", " ", 
          RowBox[{"12", "*", 
           RowBox[{"H", "^", "2"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", "*", "Pimu"}], " ", "+", " ", 
             RowBox[{"8", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], " ", "+", " ", "Pirho"}], ")"}]}]}], 
            ")"}], "*", 
           RowBox[{"h", "^", "2"}]}], " ", "+", " ", 
          RowBox[{"4", "*", "H", "*", 
           RowBox[{"(", 
            RowBox[{"48", " ", "-", " ", 
             RowBox[{"43", "*", "Pimu"}], " ", "+", " ", 
             RowBox[{"9", "*", 
              RowBox[{"Pimu", "^", "2"}]}], " ", "-", " ", 
             RowBox[{"12", "*", "Pirho"}]}], ")"}], "*", 
           RowBox[{"h", "^", "3"}]}], " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"88", "*", "Pimu"}], " ", "-", " ", 
             RowBox[{"33", "*", 
              RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
             RowBox[{"8", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "8"}], " ", "+", " ", "Pirho"}], ")"}]}]}], 
            ")"}], "*", 
           RowBox[{"h", "^", "4"}]}]}], ")"}]}], ")"}], "/", "\n", "   ", 
      RowBox[{"(", 
       RowBox[{"10", "*", 
        RowBox[{"(", 
         RowBox[{"H", " ", "-", " ", "h"}], ")"}], "*", 
        RowBox[{"h", "^", "2"}], "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", "*", "H"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], " ", "+", " ", 
              RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
         "2"}]}], ")"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"S1", "==", "S1def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.737791498063711*^9}, {
  3.7377915615953445`*^9, 3.737791588317873*^9}, {3.7377925794675636`*^9, 
  3.73779262363109*^9}, {3.7377933451013556`*^9, 3.7377933527607937`*^9}, {
  3.7377933839825797`*^9, 3.7377933840505834`*^9}}],

Cell[BoxData[
 RowBox[{"S1", "\[Equal]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["h", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"88", " ", "Pimu"}], "-", 
          RowBox[{"33", " ", 
           SuperscriptBox["Pimu", "2"]}], "+", 
          RowBox[{"8", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "8"}], "+", "Pirho"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["h", "2"], " ", 
        SuperscriptBox["H", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"7", " ", "Pimu"}], "+", 
          RowBox[{"8", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "Pirho"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["h", "3"], " ", "H", " ", 
        RowBox[{"(", 
         RowBox[{"48", "-", 
          RowBox[{"43", " ", "Pimu"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["Pimu", "2"]}], "-", 
          RowBox[{"12", " ", "Pirho"}]}], ")"}]}], "+", 
       RowBox[{"16", " ", "h", " ", 
        SuperscriptBox["H", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"4", "-", 
          RowBox[{"5", " ", "Pirho"}]}], ")"}]}], "+", 
       RowBox[{"24", " ", 
        SuperscriptBox["H", "4"], " ", "Pirho"}]}], ")"}]}], 
    RowBox[{"10", " ", 
     SuperscriptBox["h", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "h"}], "+", "H"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", "H"}], "+", 
        RowBox[{"h", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", 
           RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], 
      "2"]}]]}]}]], "Output",
 CellChangeTimes->{{3.7377926579800544`*^9, 3.7377926731119204`*^9}, 
   3.7377932480048018`*^9, 3.7377932821117525`*^9, 3.737793444537043*^9, 
   3.7377935696111965`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"S2def", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"16", "*", 
         RowBox[{"H", "^", "4"}], "*", "Pirho"}], " ", "+", " ", 
        RowBox[{"4", "*", 
         RowBox[{"H", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "24"}], "*", "Pirho"}], " ", "+", " ", 
           RowBox[{"Pimu", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], " ", "+", " ", 
              RowBox[{"20", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "2"}]}], " ", "+", " ", 
        RowBox[{"H", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Pimu", "*", 
            RowBox[{"(", 
             RowBox[{"8", " ", "-", " ", 
              RowBox[{"160", "*", "Pirho"}]}], ")"}]}], " ", "+", " ", 
           RowBox[{"128", "*", "Pirho"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"Pimu", "^", "2"}], "*", 
            RowBox[{"(", 
             RowBox[{"3", " ", "+", " ", 
              RowBox[{"30", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "3"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Pimu", "^", "2"}], "*", 
            RowBox[{"(", 
             RowBox[{"1", " ", "-", " ", 
              RowBox[{"30", "*", "Pirho"}]}], ")"}]}], " ", "-", " ", 
           RowBox[{"48", "*", "Pirho"}], " ", "+", " ", 
           RowBox[{"Pimu", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], " ", "+", " ", 
              RowBox[{"80", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "4"}]}]}], ")"}]}], ")"}], "/", "\n", "  ", 
    RowBox[{"(", 
     RowBox[{"10", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"H", " ", "-", " ", "h"}], ")"}], "^", "2"}], "*", "h", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", "*", "H"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], " ", "+", " ", 
            RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
       "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"S2", "==", "S2def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.737791498063711*^9}, {
  3.7377915615953445`*^9, 3.737791588317873*^9}, {3.7377925794675636`*^9, 
  3.737792642304158*^9}, {3.737793353625843*^9, 3.7377933841515894`*^9}}],

Cell[BoxData[
 RowBox[{"S2", "\[Equal]", 
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"16", " ", 
       SuperscriptBox["H", "4"], " ", "Pirho"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["h", "2"], " ", 
       SuperscriptBox["H", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "24"}], " ", "Pirho"}], "+", 
         RowBox[{"Pimu", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"20", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "3"], " ", "H", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Pimu", " ", 
          RowBox[{"(", 
           RowBox[{"8", "-", 
            RowBox[{"160", " ", "Pirho"}]}], ")"}]}], "+", 
         RowBox[{"128", " ", "Pirho"}], "+", 
         RowBox[{
          SuperscriptBox["Pimu", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"30", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["Pimu", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"30", " ", "Pirho"}]}], ")"}]}], "-", 
         RowBox[{"48", " ", "Pirho"}], "+", 
         RowBox[{"Pimu", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", 
            RowBox[{"80", " ", "Pirho"}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"10", " ", "h", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "h"}], "+", "H"}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "H"}], "+", 
       RowBox[{"h", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", 
          RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], "2"]}]]}]], "Output",
 CellChangeTimes->{{3.737792660055173*^9, 3.7377926750960336`*^9}, 
   3.737793248021803*^9, 3.737793282126754*^9, 3.737793444552044*^9, 
   3.7377935696271973`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["F11, F12, F21, and F22", "Subsection",
 CellChangeTimes->{{3.737791625783016*^9, 3.7377916412939034`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"F11def", "=", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"216", "*", 
           RowBox[{"H", "^", "5"}], "*", "Pirho"}], " ", "-", " ", 
          RowBox[{"8", "*", 
           RowBox[{"H", "^", "4"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "272"}], " ", "+", " ", 
             RowBox[{"201", "*", "Pirho"}]}], ")"}], "*", "h"}], " ", "+", 
          " ", 
          RowBox[{"2", "*", 
           RowBox[{"H", "^", "3"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4352"}], " ", "+", " ", 
             RowBox[{"2043", "*", "Pimu"}], " ", "+", " ", 
             RowBox[{"2136", "*", "Pirho"}], " ", "-", " ", 
             RowBox[{"252", "*", "Pimu", "*", "Pirho"}]}], ")"}], "*", 
           RowBox[{"h", "^", "2"}]}], " ", "+", " ", 
          RowBox[{"2", "*", 
           RowBox[{"H", "^", "2"}], "*", 
           RowBox[{"(", 
            RowBox[{"6528", " ", "+", " ", 
             RowBox[{"1530", "*", 
              RowBox[{"Pimu", "^", "2"}]}], " ", "-", " ", 
             RowBox[{"2664", "*", "Pirho"}], " ", "+", " ", 
             RowBox[{"Pimu", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "6163"}], " ", "+", " ", 
                RowBox[{"756", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"h", "^", "3"}]}], " ", "+", " ", "\n", "     ", 
          RowBox[{"2", "*", "H", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4352"}], " ", "-", " ", 
             RowBox[{"3096", "*", 
              RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
             RowBox[{"459", "*", 
              RowBox[{"Pimu", "^", "3"}]}], " ", "+", " ", 
             RowBox[{"Pimu", "*", 
              RowBox[{"(", 
               RowBox[{"6197", " ", "-", " ", 
                RowBox[{"756", "*", "Pirho"}]}], ")"}]}], " ", "+", " ", 
             RowBox[{"1596", "*", "Pirho"}]}], ")"}], "*", 
           RowBox[{"h", "^", "4"}]}], " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2176", " ", "+", " ", 
             RowBox[{"3048", "*", 
              RowBox[{"Pimu", "^", "2"}]}], " ", "-", " ", 
             RowBox[{"837", "*", 
              RowBox[{"Pimu", "^", "3"}]}], " ", "-", " ", 
             RowBox[{"744", "*", "Pirho"}], " ", "+", " ", 
             RowBox[{"Pimu", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4154"}], " ", "+", " ", 
                RowBox[{"504", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"h", "^", "5"}]}]}], ")"}]}], ")"}], "/", "\n", "   ", 
      RowBox[{"(", 
       RowBox[{"35", "*", 
        RowBox[{"(", 
         RowBox[{"H", " ", "-", " ", "h"}], ")"}], "*", 
        RowBox[{"h", "^", "3"}], "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", "*", "H"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], " ", "+", " ", 
              RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
         "3"}]}], ")"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"F11", "==", "F11def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.73779150469209*^9}, {
  3.737791693978917*^9, 3.7377917155441504`*^9}, {3.7377926871797247`*^9, 
  3.7377927033646507`*^9}, {3.7377927453590527`*^9, 3.7377927499643154`*^9}, {
  3.737793359721192*^9, 3.7377933835965576`*^9}}],

Cell[BoxData[
 RowBox[{"F11", "\[Equal]", 
  RowBox[{"-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"35", " ", 
      SuperscriptBox["h", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "h"}], "+", "H"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", "H"}], "+", 
         RowBox[{"h", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", 
            RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], "3"]}]], 
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"216", " ", 
        SuperscriptBox["H", "5"], " ", "Pirho"}], "-", 
       RowBox[{"8", " ", "h", " ", 
        SuperscriptBox["H", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "272"}], "+", 
          RowBox[{"201", " ", "Pirho"}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["h", "4"], " ", "H", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4352"}], "-", 
          RowBox[{"3096", " ", 
           SuperscriptBox["Pimu", "2"]}], "+", 
          RowBox[{"459", " ", 
           SuperscriptBox["Pimu", "3"]}], "+", 
          RowBox[{"Pimu", " ", 
           RowBox[{"(", 
            RowBox[{"6197", "-", 
             RowBox[{"756", " ", "Pirho"}]}], ")"}]}], "+", 
          RowBox[{"1596", " ", "Pirho"}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["h", "2"], " ", 
        SuperscriptBox["H", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4352"}], "+", 
          RowBox[{"2043", " ", "Pimu"}], "+", 
          RowBox[{"2136", " ", "Pirho"}], "-", 
          RowBox[{"252", " ", "Pimu", " ", "Pirho"}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["h", "5"], " ", 
        RowBox[{"(", 
         RowBox[{"2176", "+", 
          RowBox[{"3048", " ", 
           SuperscriptBox["Pimu", "2"]}], "-", 
          RowBox[{"837", " ", 
           SuperscriptBox["Pimu", "3"]}], "-", 
          RowBox[{"744", " ", "Pirho"}], "+", 
          RowBox[{"Pimu", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4154"}], "+", 
             RowBox[{"504", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["h", "3"], " ", 
        SuperscriptBox["H", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"6528", "+", 
          RowBox[{"1530", " ", 
           SuperscriptBox["Pimu", "2"]}], "-", 
          RowBox[{"2664", " ", "Pirho"}], "+", 
          RowBox[{"Pimu", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "6163"}], "+", 
             RowBox[{"756", " ", "Pirho"}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}]}]}]], "Output",
 CellChangeTimes->{3.7377927507133584`*^9, 3.737793248071806*^9, 
  3.737793282168756*^9, 3.7377934445700445`*^9, 3.737793569643199*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"F12def", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"336", "*", 
         RowBox[{"H", "^", "6"}], "*", "Pirho"}], " ", "+", " ", 
        RowBox[{"8", "*", 
         RowBox[{"H", "^", "5"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "248"}], " ", "+", " ", 
           RowBox[{"63", "*", "Pimu"}]}], ")"}], "*", "Pirho", "*", "h"}], 
        " ", "-", " ", 
        RowBox[{"8", "*", 
         RowBox[{"H", "^", "4"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "538"}], " ", "+", " ", 
           RowBox[{"273", "*", "Pimu"}]}], ")"}], "*", "Pirho", "*", 
         RowBox[{"h", "^", "2"}]}], " ", "+", " ", 
        RowBox[{"4", "*", 
         RowBox[{"H", "^", "3"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1024"}], "*", "Pirho"}], " ", "+", " ", 
           RowBox[{"15", "*", "Pimu", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "3"}], " ", "+", " ", 
              RowBox[{"56", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "3"}]}], " ", "+", " ", 
        RowBox[{"2", "*", 
         RowBox[{"H", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"27", "*", 
            RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
           RowBox[{"632", "*", "Pirho"}], " ", "-", " ", 
           RowBox[{"18", "*", "Pimu", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "15"}], " ", "+", " ", 
              RowBox[{"56", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "4"}]}], " ", "+", " ", "\n", "    ", 
        RowBox[{"H", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "42"}], "*", 
            RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
           RowBox[{"81", "*", 
            RowBox[{"Pimu", "^", "3"}]}], " ", "+", " ", 
           RowBox[{"448", "*", "Pirho"}], " ", "+", " ", 
           RowBox[{"12", "*", "Pimu", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "45"}], " ", "+", " ", 
              RowBox[{"14", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "5"}]}], " ", "-", " ", 
        RowBox[{"4", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", "*", 
            RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
           RowBox[{"18", "*", 
            RowBox[{"Pimu", "^", "3"}]}], " ", "+", " ", 
           RowBox[{"68", "*", "Pirho"}], " ", "-", " ", 
           RowBox[{"3", "*", "Pimu", "*", 
            RowBox[{"(", 
             RowBox[{"15", " ", "+", " ", 
              RowBox[{"14", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "6"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"35", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"H", " ", "-", " ", "h"}], ")"}], "^", "2"}], "*", 
      RowBox[{"h", "^", "3"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", "*", "H"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], " ", "+", " ", 
            RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
       "3"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"F12", "==", "F12def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.73779150469209*^9}, {
  3.737791693978917*^9, 3.7377917155441504`*^9}, {3.7377926871797247`*^9, 
  3.7377927065148306`*^9}, {3.7377927560016613`*^9, 3.7377927662912493`*^9}, {
  3.737793359832198*^9, 3.737793383673562*^9}}],

Cell[BoxData[
 RowBox[{"F12", "\[Equal]", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"35", " ", 
     SuperscriptBox["h", "3"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "h"}], "+", "H"}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", "H"}], "+", 
        RowBox[{"h", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", 
           RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], "3"]}]], 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"336", " ", 
       SuperscriptBox["H", "6"], " ", "Pirho"}], "+", 
      RowBox[{"8", " ", "h", " ", 
       SuperscriptBox["H", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "248"}], "+", 
         RowBox[{"63", " ", "Pimu"}]}], ")"}], " ", "Pirho"}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["h", "2"], " ", 
       SuperscriptBox["H", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "538"}], "+", 
         RowBox[{"273", " ", "Pimu"}]}], ")"}], " ", "Pirho"}], "+", 
      RowBox[{
       SuperscriptBox["h", "5"], " ", "H", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "42"}], " ", 
          SuperscriptBox["Pimu", "2"]}], "+", 
         RowBox[{"81", " ", 
          SuperscriptBox["Pimu", "3"]}], "+", 
         RowBox[{"448", " ", "Pirho"}], "+", 
         RowBox[{"12", " ", "Pimu", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "45"}], "+", 
            RowBox[{"14", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["h", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["Pimu", "2"]}], "+", 
         RowBox[{"18", " ", 
          SuperscriptBox["Pimu", "3"]}], "+", 
         RowBox[{"68", " ", "Pirho"}], "-", 
         RowBox[{"3", " ", "Pimu", " ", 
          RowBox[{"(", 
           RowBox[{"15", "+", 
            RowBox[{"14", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["h", "4"], " ", 
       SuperscriptBox["H", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"27", " ", 
          SuperscriptBox["Pimu", "2"]}], "+", 
         RowBox[{"632", " ", "Pirho"}], "-", 
         RowBox[{"18", " ", "Pimu", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "15"}], "+", 
            RowBox[{"56", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["h", "3"], " ", 
       SuperscriptBox["H", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1024"}], " ", "Pirho"}], "+", 
         RowBox[{"15", " ", "Pimu", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"56", " ", "Pirho"}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.737792768800393*^9, 3.737793248124809*^9, 
  3.7377932821897573`*^9, 3.7377934445860457`*^9, 3.7377935696621995`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"F21def", "=", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"192", "*", 
           RowBox[{"H", "^", "6"}], "*", "Pirho"}], " ", "+", " ", 
          RowBox[{"36", "*", 
           RowBox[{"H", "^", "5"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "16"}], " ", "+", " ", 
             RowBox[{"7", "*", "Pimu"}]}], ")"}], "*", "Pirho", "*", "h"}], 
          " ", "+", " ", 
          RowBox[{"4", "*", 
           RowBox[{"H", "^", "4"}], "*", "Pimu", "*", 
           RowBox[{"(", 
            RowBox[{"38", " ", "-", " ", 
             RowBox[{"189", "*", "Pirho"}]}], ")"}], "*", 
           RowBox[{"h", "^", "2"}]}], " ", "+", " ", 
          RowBox[{"3", "*", 
           RowBox[{"H", "^", "3"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", "*", 
              RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
             RowBox[{"640", "*", "Pirho"}], " ", "+", " ", 
             RowBox[{"24", "*", "Pimu", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "10"}], " ", "+", " ", 
                RowBox[{"7", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"h", "^", "3"}]}], " ", "-", " ", "\n", "      ", 
          RowBox[{"3", "*", 
           RowBox[{"H", "^", "2"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", "*", 
              RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
             RowBox[{"27", "*", 
              RowBox[{"Pimu", "^", "3"}]}], " ", "+", " ", 
             RowBox[{"960", "*", "Pirho"}], " ", "-", " ", 
             RowBox[{"8", "*", "Pimu", "*", 
              RowBox[{"(", 
               RowBox[{"52", " ", "+", " ", 
                RowBox[{"21", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"h", "^", "4"}]}], " ", "+", " ", 
          RowBox[{"H", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"103", "*", 
              RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
             RowBox[{"174", "*", 
              RowBox[{"Pimu", "^", "3"}]}], " ", "+", " ", 
             RowBox[{"1728", "*", "Pirho"}], " ", "-", " ", 
             RowBox[{"4", "*", "Pimu", "*", 
              RowBox[{"(", 
               RowBox[{"236", " ", "+", " ", 
                RowBox[{"189", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"h", "^", "5"}]}], " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "103"}], "*", 
              RowBox[{"Pimu", "^", "2"}]}], " ", "-", " ", 
             RowBox[{"51", "*", 
              RowBox[{"Pimu", "^", "3"}]}], " ", "-", " ", 
             RowBox[{"384", "*", "Pirho"}], " ", "+", " ", 
             RowBox[{"12", "*", "Pimu", "*", 
              RowBox[{"(", 
               RowBox[{"22", " ", "+", " ", 
                RowBox[{"21", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"h", "^", "6"}]}]}], ")"}]}], ")"}], "/", "\n", "    ", 
      RowBox[{"(", 
       RowBox[{"35", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"H", " ", "-", " ", "h"}], ")"}], "^", "3"}], "*", 
        RowBox[{"h", "^", "2"}], "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", "*", "H"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], " ", "+", " ", 
              RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
         "3"}]}], ")"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"F21", "==", "F21def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.73779150469209*^9}, {
  3.737791693978917*^9, 3.7377917155441504`*^9}, {3.7377926871797247`*^9, 
  3.7377927065148306`*^9}, {3.7377927560016613`*^9, 3.737792779489004*^9}, {
  3.7377933598882017`*^9, 3.737793383697563*^9}}],

Cell[BoxData[
 RowBox[{"F21", "\[Equal]", 
  RowBox[{"-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"35", " ", 
      SuperscriptBox["h", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "h"}], "+", "H"}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", "H"}], "+", 
         RowBox[{"h", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", 
            RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], "3"]}]], 
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["h", "2"], " ", 
        SuperscriptBox["H", "4"], " ", "Pimu", " ", 
        RowBox[{"(", 
         RowBox[{"38", "-", 
          RowBox[{"189", " ", "Pirho"}]}], ")"}]}], "+", 
       RowBox[{"192", " ", 
        SuperscriptBox["H", "6"], " ", "Pirho"}], "+", 
       RowBox[{"36", " ", "h", " ", 
        SuperscriptBox["H", "5"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "16"}], "+", 
          RowBox[{"7", " ", "Pimu"}]}], ")"}], " ", "Pirho"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["h", "3"], " ", 
        SuperscriptBox["H", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["Pimu", "2"]}], "+", 
          RowBox[{"640", " ", "Pirho"}], "+", 
          RowBox[{"24", " ", "Pimu", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "10"}], "+", 
             RowBox[{"7", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["h", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "103"}], " ", 
           SuperscriptBox["Pimu", "2"]}], "-", 
          RowBox[{"51", " ", 
           SuperscriptBox["Pimu", "3"]}], "-", 
          RowBox[{"384", " ", "Pirho"}], "+", 
          RowBox[{"12", " ", "Pimu", " ", 
           RowBox[{"(", 
            RowBox[{"22", "+", 
             RowBox[{"21", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["h", "4"], " ", 
        SuperscriptBox["H", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["Pimu", "2"]}], "+", 
          RowBox[{"27", " ", 
           SuperscriptBox["Pimu", "3"]}], "+", 
          RowBox[{"960", " ", "Pirho"}], "-", 
          RowBox[{"8", " ", "Pimu", " ", 
           RowBox[{"(", 
            RowBox[{"52", "+", 
             RowBox[{"21", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["h", "5"], " ", "H", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"103", " ", 
           SuperscriptBox["Pimu", "2"]}], "+", 
          RowBox[{"174", " ", 
           SuperscriptBox["Pimu", "3"]}], "+", 
          RowBox[{"1728", " ", "Pirho"}], "-", 
          RowBox[{"4", " ", "Pimu", " ", 
           RowBox[{"(", 
            RowBox[{"236", "+", 
             RowBox[{"189", " ", "Pirho"}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}]}]}]], "Output",
 CellChangeTimes->{3.7377927799240294`*^9, 3.7377932481818123`*^9, 
  3.73779328223876*^9, 3.7377934446050467`*^9, 3.7377935697132025`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"F22def", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"24", "*", 
         RowBox[{"H", "^", "5"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "24"}], " ", "+", " ", 
           RowBox[{"7", "*", "Pimu"}]}], ")"}], "*", "Pirho"}], " ", "-", " ", 
        RowBox[{"8", "*", 
         RowBox[{"H", "^", "4"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "88"}], " ", "+", " ", 
           RowBox[{"133", "*", "Pimu"}]}], ")"}], "*", "Pirho", "*", "h"}], 
        " ", "-", " ", 
        RowBox[{"16", "*", 
         RowBox[{"H", "^", "3"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "184"}], " ", "+", " ", 
           RowBox[{"77", "*", "Pimu"}]}], ")"}], "*", "Pirho", "*", 
         RowBox[{"h", "^", "2"}]}], " ", "-", " ", 
        RowBox[{"6", "*", 
         RowBox[{"H", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1216", "*", "Pirho"}], " ", "-", " ", 
           RowBox[{"1400", "*", "Pimu", "*", "Pirho"}], " ", "+", " ", 
           RowBox[{"5", "*", 
            RowBox[{"Pimu", "^", "2"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "5"}], " ", "+", " ", 
              RowBox[{"84", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "3"}]}], " ", "+", " ", "\n", "     ", 
        RowBox[{"2", "*", "H", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2912", "*", "Pirho"}], " ", "-", " ", 
           RowBox[{"4844", "*", "Pimu", "*", "Pirho"}], " ", "-", " ", 
           RowBox[{"9", "*", 
            RowBox[{"Pimu", "^", "3"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], " ", "+", " ", 
              RowBox[{"35", "*", "Pirho"}]}], ")"}]}], " ", "+", " ", 
           RowBox[{"30", "*", 
            RowBox[{"Pimu", "^", "2"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "5"}], " ", "+", " ", 
              RowBox[{"84", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "4"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1600"}], "*", "Pirho"}], " ", "+", " ", 
           RowBox[{"3416", "*", "Pimu", "*", "Pirho"}], " ", "+", " ", 
           RowBox[{"9", "*", 
            RowBox[{"Pimu", "^", "3"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "11"}], " ", "+", " ", 
              RowBox[{"70", "*", "Pirho"}]}], ")"}]}], " ", "-", " ", 
           RowBox[{"30", "*", 
            RowBox[{"Pimu", "^", "2"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "5"}], " ", "+", " ", 
              RowBox[{"84", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "5"}]}]}], ")"}]}], ")"}], "/", "\n", "   ", 
    RowBox[{"(", 
     RowBox[{"35", "*", "h", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "H"}], " ", "+", " ", "h"}], ")"}], "^", "3"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", "*", "H"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], " ", "+", " ", 
            RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
       "3"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"F22", "==", "F22def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.73779150469209*^9}, {
  3.737791693978917*^9, 3.7377917155441504`*^9}, {3.7377926871797247`*^9, 
  3.7377927065148306`*^9}, {3.7377927560016613`*^9, 3.7377927866674147`*^9}, {
  3.7377933599072027`*^9, 3.7377933837155643`*^9}}],

Cell[BoxData[
 RowBox[{"F22", "\[Equal]", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"35", " ", "h", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"h", "-", "H"}], ")"}], "3"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", "H"}], "+", 
        RowBox[{"h", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", 
           RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], "3"]}]], 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"24", " ", 
       SuperscriptBox["H", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "24"}], "+", 
         RowBox[{"7", " ", "Pimu"}]}], ")"}], " ", "Pirho"}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["h", "2"], " ", 
       SuperscriptBox["H", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "184"}], "+", 
         RowBox[{"77", " ", "Pimu"}]}], ")"}], " ", "Pirho"}], "-", 
      RowBox[{"8", " ", "h", " ", 
       SuperscriptBox["H", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "88"}], "+", 
         RowBox[{"133", " ", "Pimu"}]}], ")"}], " ", "Pirho"}], "+", 
      RowBox[{
       SuperscriptBox["h", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1600"}], " ", "Pirho"}], "+", 
         RowBox[{"3416", " ", "Pimu", " ", "Pirho"}], "+", 
         RowBox[{"9", " ", 
          SuperscriptBox["Pimu", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "11"}], "+", 
            RowBox[{"70", " ", "Pirho"}]}], ")"}]}], "-", 
         RowBox[{"30", " ", 
          SuperscriptBox["Pimu", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "+", 
            RowBox[{"84", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["h", "3"], " ", 
       SuperscriptBox["H", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1216", " ", "Pirho"}], "-", 
         RowBox[{"1400", " ", "Pimu", " ", "Pirho"}], "+", 
         RowBox[{"5", " ", 
          SuperscriptBox["Pimu", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "+", 
            RowBox[{"84", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["h", "4"], " ", "H", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2912", " ", "Pirho"}], "-", 
         RowBox[{"4844", " ", "Pimu", " ", "Pirho"}], "-", 
         RowBox[{"9", " ", 
          SuperscriptBox["Pimu", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", 
            RowBox[{"35", " ", "Pirho"}]}], ")"}]}], "+", 
         RowBox[{"30", " ", 
          SuperscriptBox["Pimu", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "+", 
            RowBox[{"84", " ", "Pirho"}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.7377927874474597`*^9, 3.7377932482418156`*^9, 
  3.737793282293763*^9, 3.737793444624048*^9, 3.7377935697862067`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["G11, G12=G21, and G22", "Subsection",
 CellChangeTimes->{{3.7377916481822977`*^9, 3.7377916585028877`*^9}, {
  3.7377917354632893`*^9, 3.7377917359033146`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"G11def", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"18", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"144", "*", 
         RowBox[{"H", "^", "6"}], "*", "Pirho"}], " ", "+", " ", 
        RowBox[{"8", "*", 
         RowBox[{"H", "^", "5"}], "*", 
         RowBox[{"(", 
          RowBox[{"96", " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "146"}], " ", "+", " ", 
              RowBox[{"27", "*", "Pimu"}]}], ")"}], "*", "Pirho"}]}], ")"}], 
         "*", "h"}], " ", "-", " ", 
        RowBox[{"4", "*", 
         RowBox[{"H", "^", "4"}], "*", 
         RowBox[{"(", 
          RowBox[{"960", " ", "-", " ", 
           RowBox[{"872", "*", "Pirho"}], " ", "+", " ", 
           RowBox[{"9", "*", "Pimu", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "59"}], " ", "+", " ", 
              RowBox[{"50", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "2"}]}], " ", "+", " ", 
        RowBox[{"4", "*", 
         RowBox[{"H", "^", "3"}], "*", 
         RowBox[{"(", 
          RowBox[{"1920", " ", "-", " ", 
           RowBox[{"1288", "*", "Pirho"}], " ", "-", " ", 
           RowBox[{"9", "*", 
            RowBox[{"Pimu", "^", "2"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "57"}], " ", "+", " ", 
              RowBox[{"14", "*", "Pirho"}]}], ")"}]}], " ", "+", " ", 
           RowBox[{"Pimu", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2099"}], " ", "+", " ", 
              RowBox[{"1116", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "3"}]}], " ", "+", " ", "\n", "    ", 
        RowBox[{
         RowBox[{"H", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "7680"}], " ", "+", " ", 
           RowBox[{"1053", "*", 
            RowBox[{"Pimu", "^", "3"}]}], " ", "+", " ", 
           RowBox[{"Pimu", "*", 
            RowBox[{"(", 
             RowBox[{"12444", " ", "-", " ", 
              RowBox[{"4752", "*", "Pirho"}]}], ")"}]}], " ", "+", " ", 
           RowBox[{"4048", "*", "Pirho"}], " ", "+", " ", 
           RowBox[{"6", "*", 
            RowBox[{"Pimu", "^", "2"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1052"}], " ", "+", " ", 
              RowBox[{"189", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "4"}]}], " ", "+", " ", 
        RowBox[{"H", "*", 
         RowBox[{"(", 
          RowBox[{"3840", " ", "-", " ", 
           RowBox[{"2142", "*", 
            RowBox[{"Pimu", "^", "3"}]}], " ", "+", " ", 
           RowBox[{"243", "*", 
            RowBox[{"Pimu", "^", "4"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{"Pimu", "^", "2"}], "*", 
            RowBox[{"(", 
             RowBox[{"6402", " ", "-", " ", 
              RowBox[{"756", "*", "Pirho"}]}], ")"}]}], " ", "-", " ", 
           RowBox[{"1616", "*", "Pirho"}], " ", "+", " ", 
           RowBox[{"12", "*", "Pimu", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "683"}], " ", "+", " ", 
              RowBox[{"186", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "5"}]}], " ", "-", " ", "\n", "    ", 
        RowBox[{"2", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], " ", "+", " ", 
           RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "132"}], "*", 
            RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
           RowBox[{"36", "*", 
            RowBox[{"Pimu", "^", "3"}]}], " ", "+", " ", 
           RowBox[{"Pimu", "*", 
            RowBox[{"(", 
             RowBox[{"181", " ", "-", " ", 
              RowBox[{"21", "*", "Pirho"}]}], ")"}]}], " ", "+", " ", 
           RowBox[{"32", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "3"}], " ", "+", " ", "Pirho"}], ")"}]}]}], ")"}], 
         "*", 
         RowBox[{"h", "^", "6"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"35", "*", 
      RowBox[{"(", 
       RowBox[{"H", " ", "-", " ", "h"}], ")"}], "*", 
      RowBox[{"h", "^", "4"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", "*", "H"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], " ", "+", " ", 
            RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
       "4"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"G11", "\[Equal]", "G11def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.737791513184576*^9}, {
  3.7377916761228957`*^9, 3.737791684570379*^9}, {3.73779271035305*^9, 
  3.7377927127561874`*^9}, {3.7377927926687584`*^9, 3.737792802589326*^9}, {
  3.7377933599282036`*^9, 3.7377933837385654`*^9}}],

Cell[BoxData[
 RowBox[{"G11", "\[Equal]", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"35", " ", 
     SuperscriptBox["h", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "h"}], "+", "H"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", "H"}], "+", 
        RowBox[{"h", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", 
           RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], "4"]}]], 
   RowBox[{"18", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["h", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", 
         RowBox[{"3", " ", "Pimu"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "132"}], " ", 
          SuperscriptBox["Pimu", "2"]}], "+", 
         RowBox[{"36", " ", 
          SuperscriptBox["Pimu", "3"]}], "+", 
         RowBox[{"Pimu", " ", 
          RowBox[{"(", 
           RowBox[{"181", "-", 
            RowBox[{"21", " ", "Pirho"}]}], ")"}]}], "+", 
         RowBox[{"32", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "Pirho"}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"144", " ", 
       SuperscriptBox["H", "6"], " ", "Pirho"}], "+", 
      RowBox[{"8", " ", "h", " ", 
       SuperscriptBox["H", "5"], " ", 
       RowBox[{"(", 
        RowBox[{"96", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "146"}], "+", 
            RowBox[{"27", " ", "Pimu"}]}], ")"}], " ", "Pirho"}]}], ")"}]}], 
      "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["h", "2"], " ", 
       SuperscriptBox["H", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"960", "-", 
         RowBox[{"872", " ", "Pirho"}], "+", 
         RowBox[{"9", " ", "Pimu", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "59"}], "+", 
            RowBox[{"50", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "5"], " ", "H", " ", 
       RowBox[{"(", 
        RowBox[{"3840", "-", 
         RowBox[{"2142", " ", 
          SuperscriptBox["Pimu", "3"]}], "+", 
         RowBox[{"243", " ", 
          SuperscriptBox["Pimu", "4"]}], "+", 
         RowBox[{
          SuperscriptBox["Pimu", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"6402", "-", 
            RowBox[{"756", " ", "Pirho"}]}], ")"}]}], "-", 
         RowBox[{"1616", " ", "Pirho"}], "+", 
         RowBox[{"12", " ", "Pimu", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "683"}], "+", 
            RowBox[{"186", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "4"], " ", 
       SuperscriptBox["H", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "7680"}], "+", 
         RowBox[{"1053", " ", 
          SuperscriptBox["Pimu", "3"]}], "+", 
         RowBox[{"Pimu", " ", 
          RowBox[{"(", 
           RowBox[{"12444", "-", 
            RowBox[{"4752", " ", "Pirho"}]}], ")"}]}], "+", 
         RowBox[{"4048", " ", "Pirho"}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["Pimu", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1052"}], "+", 
            RowBox[{"189", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["h", "3"], " ", 
       SuperscriptBox["H", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"1920", "-", 
         RowBox[{"1288", " ", "Pirho"}], "-", 
         RowBox[{"9", " ", 
          SuperscriptBox["Pimu", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "57"}], "+", 
            RowBox[{"14", " ", "Pirho"}]}], ")"}]}], "+", 
         RowBox[{"Pimu", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2099"}], "+", 
            RowBox[{"1116", " ", "Pirho"}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.7377928041084127`*^9, 3.737793248303819*^9, 
  3.7377932823517666`*^9, 3.7377934446480494`*^9, 3.73779356983921*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"G2112def", "=", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"256", "*", 
           RowBox[{"H", "^", "7"}], "*", "Pirho"}], " ", "+", " ", 
          RowBox[{"64", "*", 
           RowBox[{"H", "^", "6"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "22"}], " ", "+", " ", 
             RowBox[{"9", "*", "Pimu"}]}], ")"}], "*", "Pirho", "*", "h"}], 
          " ", "+", " ", 
          RowBox[{"8", "*", 
           RowBox[{"H", "^", "5"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"352", "*", "Pirho"}], " ", "+", " ", 
             RowBox[{"63", "*", 
              RowBox[{"Pimu", "^", "2"}], "*", "Pirho"}], " ", "-", " ", 
             RowBox[{"4", "*", "Pimu", "*", 
              RowBox[{"(", 
               RowBox[{"5", " ", "+", " ", 
                RowBox[{"58", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"h", "^", "2"}]}], " ", "-", " ", 
          RowBox[{"8", "*", 
           RowBox[{"H", "^", "4"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"240", "*", "Pirho"}], " ", "-", " ", 
             RowBox[{"8", "*", "Pimu", "*", 
              RowBox[{"(", 
               RowBox[{"5", " ", "+", " ", 
                RowBox[{"18", "*", "Pirho"}]}], ")"}]}], " ", "+", " ", 
             RowBox[{"3", "*", 
              RowBox[{"Pimu", "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "17"}], " ", "+", " ", 
                RowBox[{"49", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"h", "^", "3"}]}], " ", "+", " ", "\n", "      ", 
          RowBox[{"2", "*", 
           RowBox[{"H", "^", "3"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"99", "*", 
              RowBox[{"Pimu", "^", "3"}]}], " ", "-", " ", 
             RowBox[{"640", "*", "Pirho"}], " ", "+", " ", 
             RowBox[{"32", "*", "Pimu", "*", 
              RowBox[{"(", 
               RowBox[{"5", " ", "+", " ", 
                RowBox[{"38", "*", "Pirho"}]}], ")"}]}], " ", "+", " ", 
             RowBox[{"4", "*", 
              RowBox[{"Pimu", "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "173"}], " ", "+", " ", 
                RowBox[{"42", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"h", "^", "4"}]}], " ", "+", " ", 
          RowBox[{
           RowBox[{"H", "^", "2"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "360"}], "*", 
              RowBox[{"Pimu", "^", "3"}]}], " ", "-", " ", 
             RowBox[{"27", "*", 
              RowBox[{"Pimu", "^", "4"}]}], " ", "+", " ", 
             RowBox[{"2944", "*", "Pirho"}], " ", "-", " ", 
             RowBox[{"64", "*", "Pimu", "*", 
              RowBox[{"(", 
               RowBox[{"20", " ", "+", " ", 
                RowBox[{"67", "*", "Pirho"}]}], ")"}]}], " ", "+", " ", 
             RowBox[{"8", "*", 
              RowBox[{"Pimu", "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{"235", " ", "+", " ", 
                RowBox[{"126", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"h", "^", "5"}]}], " ", "+", " ", "\n", "      ", 
          RowBox[{"2", "*", "H", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"81", "*", 
              RowBox[{"Pimu", "^", "3"}]}], " ", "+", " ", 
             RowBox[{"45", "*", 
              RowBox[{"Pimu", "^", "4"}]}], " ", "-", " ", 
             RowBox[{"896", "*", "Pirho"}], " ", "-", " ", 
             RowBox[{"20", "*", 
              RowBox[{"Pimu", "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{"31", " ", "+", " ", 
                RowBox[{"21", "*", "Pirho"}]}], ")"}]}], " ", "+", " ", 
             RowBox[{"16", "*", "Pimu", "*", 
              RowBox[{"(", 
               RowBox[{"35", " ", "+", " ", 
                RowBox[{"78", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"h", "^", "6"}]}], " ", "-", " ", 
          RowBox[{"2", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], " ", "+", " ", 
             RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
             RowBox[{"9", "*", 
              RowBox[{"Pimu", "^", "3"}]}], " ", "+", " ", 
             RowBox[{"48", "*", "Pirho"}], " ", "-", " ", 
             RowBox[{"4", "*", "Pimu", "*", 
              RowBox[{"(", 
               RowBox[{"10", " ", "+", " ", 
                RowBox[{"7", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"h", "^", "7"}]}]}], ")"}]}], ")"}], "/", "\n", "    ", 
      RowBox[{"(", 
       RowBox[{"35", "*", 
        RowBox[{"h", "^", "3"}], "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "H"}], " ", "+", " ", "h"}], ")"}], "^", "3"}], "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", "*", "H"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], " ", "+", " ", 
              RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
         "4"}]}], ")"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"G12", "\[Equal]", "G21", "==", "G2112def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.737791513184576*^9}, {
  3.7377916761228957`*^9, 3.737791684570379*^9}, {3.73779271035305*^9, 
  3.7377927127561874`*^9}, {3.7377927926687584`*^9, 3.737792834069126*^9}, {
  3.737793359948205*^9, 3.737793383764567*^9}, {3.7377935111588535`*^9, 
  3.73779351127386*^9}}],

Cell[BoxData[
 RowBox[{"G12", "\[Equal]", "G21", "\[Equal]", 
  RowBox[{"-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"35", " ", 
      SuperscriptBox["h", "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"h", "-", "H"}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", "H"}], "+", 
         RowBox[{"h", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", 
            RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], "4"]}]], 
    RowBox[{"9", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"256", " ", 
        SuperscriptBox["H", "7"], " ", "Pirho"}], "+", 
       RowBox[{"64", " ", "h", " ", 
        SuperscriptBox["H", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "22"}], "+", 
          RowBox[{"9", " ", "Pimu"}]}], ")"}], " ", "Pirho"}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["h", "7"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", 
          RowBox[{"3", " ", "Pimu"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"12", " ", 
           SuperscriptBox["Pimu", "2"]}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["Pimu", "3"]}], "+", 
          RowBox[{"48", " ", "Pirho"}], "-", 
          RowBox[{"4", " ", "Pimu", " ", 
           RowBox[{"(", 
            RowBox[{"10", "+", 
             RowBox[{"7", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["h", "4"], " ", 
        SuperscriptBox["H", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"99", " ", 
           SuperscriptBox["Pimu", "3"]}], "-", 
          RowBox[{"640", " ", "Pirho"}], "+", 
          RowBox[{"32", " ", "Pimu", " ", 
           RowBox[{"(", 
            RowBox[{"5", "+", 
             RowBox[{"38", " ", "Pirho"}]}], ")"}]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["Pimu", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "173"}], "+", 
             RowBox[{"42", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["h", "3"], " ", 
        SuperscriptBox["H", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"240", " ", "Pirho"}], "-", 
          RowBox[{"8", " ", "Pimu", " ", 
           RowBox[{"(", 
            RowBox[{"5", "+", 
             RowBox[{"18", " ", "Pirho"}]}], ")"}]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["Pimu", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "17"}], "+", 
             RowBox[{"49", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["h", "2"], " ", 
        SuperscriptBox["H", "5"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"352", " ", "Pirho"}], "+", 
          RowBox[{"63", " ", 
           SuperscriptBox["Pimu", "2"], " ", "Pirho"}], "-", 
          RowBox[{"4", " ", "Pimu", " ", 
           RowBox[{"(", 
            RowBox[{"5", "+", 
             RowBox[{"58", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["h", "6"], " ", "H", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"81", " ", 
           SuperscriptBox["Pimu", "3"]}], "+", 
          RowBox[{"45", " ", 
           SuperscriptBox["Pimu", "4"]}], "-", 
          RowBox[{"896", " ", "Pirho"}], "-", 
          RowBox[{"20", " ", 
           SuperscriptBox["Pimu", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"31", "+", 
             RowBox[{"21", " ", "Pirho"}]}], ")"}]}], "+", 
          RowBox[{"16", " ", "Pimu", " ", 
           RowBox[{"(", 
            RowBox[{"35", "+", 
             RowBox[{"78", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["h", "5"], " ", 
        SuperscriptBox["H", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "360"}], " ", 
           SuperscriptBox["Pimu", "3"]}], "-", 
          RowBox[{"27", " ", 
           SuperscriptBox["Pimu", "4"]}], "+", 
          RowBox[{"2944", " ", "Pirho"}], "-", 
          RowBox[{"64", " ", "Pimu", " ", 
           RowBox[{"(", 
            RowBox[{"20", "+", 
             RowBox[{"67", " ", "Pirho"}]}], ")"}]}], "+", 
          RowBox[{"8", " ", 
           SuperscriptBox["Pimu", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"235", "+", 
             RowBox[{"126", " ", "Pirho"}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}]}]}]], "Output",
 CellChangeTimes->{{3.7377928281967907`*^9, 3.737792835028181*^9}, 
   3.7377932483698225`*^9, 3.7377932824127703`*^9, 3.7377934447070527`*^9, 
   3.7377935120299034`*^9, 3.7377935698912125`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"G22def", "=", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"128", "*", 
           RowBox[{"H", "^", "6"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], " ", "+", " ", "Pimu"}], ")"}], "*", 
           "Pirho"}], " ", "+", " ", 
          RowBox[{"8", "*", 
           RowBox[{"H", "^", "5"}], "*", 
           RowBox[{"(", 
            RowBox[{"192", " ", "-", " ", 
             RowBox[{"136", "*", "Pimu"}], " ", "+", " ", 
             RowBox[{"21", "*", 
              RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", "Pirho", "*", "h"}],
           " ", "+", " ", 
          RowBox[{"16", "*", 
           RowBox[{"H", "^", "4"}], "*", "Pimu", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Pimu", "*", 
              RowBox[{"(", 
               RowBox[{"19", " ", "-", " ", 
                RowBox[{"42", "*", "Pirho"}]}], ")"}]}], " ", "+", " ", 
             RowBox[{"4", "*", "Pirho"}]}], ")"}], "*", 
           RowBox[{"h", "^", "2"}]}], " ", "+", " ", 
          RowBox[{"2", "*", 
           RowBox[{"H", "^", "3"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"117", "*", 
              RowBox[{"Pimu", "^", "3"}]}], " ", "-", " ", 
             RowBox[{"2560", "*", "Pirho"}], " ", "+", " ", 
             RowBox[{"4032", "*", "Pimu", "*", "Pirho"}], " ", "-", " ", 
             RowBox[{"24", "*", 
              RowBox[{"Pimu", "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{"17", " ", "+", " ", 
                RowBox[{"49", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"h", "^", "3"}]}], " ", "+", " ", "\n", "      ", 
          RowBox[{
           RowBox[{"H", "^", "2"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"45", "*", 
              RowBox[{"Pimu", "^", "4"}]}], " ", "+", " ", 
             RowBox[{"7680", "*", "Pirho"}], " ", "-", " ", 
             RowBox[{"15616", "*", "Pimu", "*", "Pirho"}], " ", "-", " ", 
             RowBox[{"24", "*", 
              RowBox[{"Pimu", "^", "3"}], "*", 
              RowBox[{"(", 
               RowBox[{"17", " ", "+", " ", 
                RowBox[{"70", "*", "Pirho"}]}], ")"}]}], " ", "+", " ", 
             RowBox[{"48", "*", 
              RowBox[{"Pimu", "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{"13", " ", "+", " ", 
                RowBox[{"196", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"h", "^", "4"}]}], " ", "-", " ", 
          RowBox[{"H", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4608", "*", "Pirho"}], " ", "-", " ", 
             RowBox[{"11456", "*", "Pimu", "*", "Pirho"}], " ", "+", " ", 
             RowBox[{"9", "*", 
              RowBox[{"Pimu", "^", "4"}], "*", 
              RowBox[{"(", 
               RowBox[{"3", " ", "+", " ", 
                RowBox[{"35", "*", "Pirho"}]}], ")"}]}], " ", "-", " ", 
             RowBox[{"42", "*", 
              RowBox[{"Pimu", "^", "3"}], "*", 
              RowBox[{"(", 
               RowBox[{"1", " ", "+", " ", 
                RowBox[{"80", "*", "Pirho"}]}], ")"}]}], " ", "+", " ", 
             RowBox[{"8", "*", 
              RowBox[{"Pimu", "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{"2", " ", "+", " ", 
                RowBox[{"1239", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", "\n",
            "       ", 
           RowBox[{"h", "^", "5"}]}], " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], " ", "+", " ", 
             RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Pimu", "^", "2"}], "*", 
              RowBox[{"(", 
               RowBox[{"24", " ", "-", " ", 
                RowBox[{"420", "*", "Pirho"}]}], ")"}]}], " ", "-", " ", 
             RowBox[{"256", "*", "Pirho"}], " ", "+", " ", 
             RowBox[{"560", "*", "Pimu", "*", "Pirho"}], " ", "+", " ", 
             RowBox[{"15", "*", 
              RowBox[{"Pimu", "^", "3"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], " ", "+", " ", 
                RowBox[{"7", "*", "Pirho"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"h", "^", "6"}]}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"35", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"H", " ", "-", " ", "h"}], ")"}], "^", "4"}], "*", "h", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", "*", "H"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], " ", "+", " ", 
              RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
         "4"}]}], ")"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"G22", "==", "G22def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.737791513184576*^9}, {
  3.7377916761228957`*^9, 3.737791684570379*^9}, {3.73779271035305*^9, 
  3.7377927127561874`*^9}, {3.7377927926687584`*^9, 3.7377928484599495`*^9}, {
  3.737793359972206*^9, 3.7377933837865686`*^9}}],

Cell[BoxData[
 RowBox[{"G22", "\[Equal]", 
  RowBox[{"-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"35", " ", "h", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "h"}], "+", "H"}], ")"}], "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", "H"}], "+", 
         RowBox[{"h", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", 
            RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], "4"]}]], 
    RowBox[{"9", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"128", " ", 
        SuperscriptBox["H", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", "Pimu"}], ")"}], " ", "Pirho"}], "+", 
       RowBox[{"8", " ", "h", " ", 
        SuperscriptBox["H", "5"], " ", 
        RowBox[{"(", 
         RowBox[{"192", "-", 
          RowBox[{"136", " ", "Pimu"}], "+", 
          RowBox[{"21", " ", 
           SuperscriptBox["Pimu", "2"]}]}], ")"}], " ", "Pirho"}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["h", "2"], " ", 
        SuperscriptBox["H", "4"], " ", "Pimu", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Pimu", " ", 
           RowBox[{"(", 
            RowBox[{"19", "-", 
             RowBox[{"42", " ", "Pirho"}]}], ")"}]}], "+", 
          RowBox[{"4", " ", "Pirho"}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["h", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", 
          RowBox[{"3", " ", "Pimu"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["Pimu", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"24", "-", 
             RowBox[{"420", " ", "Pirho"}]}], ")"}]}], "-", 
          RowBox[{"256", " ", "Pirho"}], "+", 
          RowBox[{"560", " ", "Pimu", " ", "Pirho"}], "+", 
          RowBox[{"15", " ", 
           SuperscriptBox["Pimu", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"7", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["h", "3"], " ", 
        SuperscriptBox["H", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"117", " ", 
           SuperscriptBox["Pimu", "3"]}], "-", 
          RowBox[{"2560", " ", "Pirho"}], "+", 
          RowBox[{"4032", " ", "Pimu", " ", "Pirho"}], "-", 
          RowBox[{"24", " ", 
           SuperscriptBox["Pimu", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"17", "+", 
             RowBox[{"49", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["h", "4"], " ", 
        SuperscriptBox["H", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"45", " ", 
           SuperscriptBox["Pimu", "4"]}], "+", 
          RowBox[{"7680", " ", "Pirho"}], "-", 
          RowBox[{"15616", " ", "Pimu", " ", "Pirho"}], "-", 
          RowBox[{"24", " ", 
           SuperscriptBox["Pimu", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"17", "+", 
             RowBox[{"70", " ", "Pirho"}]}], ")"}]}], "+", 
          RowBox[{"48", " ", 
           SuperscriptBox["Pimu", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"13", "+", 
             RowBox[{"196", " ", "Pirho"}]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["h", "5"], " ", "H", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4608", " ", "Pirho"}], "-", 
          RowBox[{"11456", " ", "Pimu", " ", "Pirho"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["Pimu", "4"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"35", " ", "Pirho"}]}], ")"}]}], "-", 
          RowBox[{"42", " ", 
           SuperscriptBox["Pimu", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"80", " ", "Pirho"}]}], ")"}]}], "+", 
          RowBox[{"8", " ", 
           SuperscriptBox["Pimu", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{"1239", " ", "Pirho"}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}]}]}]], "Output",
 CellChangeTimes->{3.7377928497600236`*^9, 3.7377932484328265`*^9, 
  3.737793282475774*^9, 3.737793444730054*^9, 3.7377935699132137`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["J1 and J2", "Subsection",
 CellChangeTimes->{{3.737791666279332*^9, 3.737791668071435*^9}, {
  3.737791732799137*^9, 3.7377917332061605`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"J1def", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"5", "*", 
        RowBox[{"(", 
         RowBox[{"H", " ", "-", " ", "h"}], ")"}], "*", 
        RowBox[{"h", "^", "4"}], "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", "*", "H"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], " ", "+", " ", 
              RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
         "4"}]}], ")"}]}], ")"}], "*", "6", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"384", "*", 
       RowBox[{"H", "^", "6"}], "*", "Pimu"}], " ", "+", " ", 
      RowBox[{"32", "*", 
       RowBox[{"H", "^", "5"}], "*", 
       RowBox[{"(", 
        RowBox[{"32", " ", "-", " ", 
         RowBox[{"78", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"27", "*", 
          RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", "h"}], " ", "+", " ", 
      RowBox[{"8", "*", 
       RowBox[{"H", "^", "4"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "640"}], " ", "+", " ", 
         RowBox[{"1236", "*", "Pimu"}], " ", "-", " ", 
         RowBox[{"654", "*", 
          RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
         RowBox[{"81", "*", 
          RowBox[{"Pimu", "^", "3"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "2"}]}], " ", "-", " ", "\n", "   ", 
      RowBox[{"8", "*", 
       RowBox[{"H", "^", "3"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1280"}], " ", "+", " ", 
         RowBox[{"2772", "*", "Pimu"}], " ", "-", " ", 
         RowBox[{"1965", "*", 
          RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
         RowBox[{"459", "*", 
          RowBox[{"Pimu", "^", "3"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "3"}]}], " ", "-", " ", 
      RowBox[{"2", "*", 
       RowBox[{"H", "^", "2"}], "*", 
       RowBox[{"(", 
        RowBox[{"5120", " ", "-", " ", 
         RowBox[{"12912", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"11472", "*", 
          RowBox[{"Pimu", "^", "2"}]}], " ", "-", " ", 
         RowBox[{"4050", "*", 
          RowBox[{"Pimu", "^", "3"}]}], " ", "+", " ", 
         RowBox[{"405", "*", 
          RowBox[{"Pimu", "^", "4"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "4"}]}], " ", "+", " ", 
      RowBox[{"2", "*", "H", "*", 
       RowBox[{"(", 
        RowBox[{"2560", " ", "-", " ", 
         RowBox[{"7248", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"7548", "*", 
          RowBox[{"Pimu", "^", "2"}]}], " ", "-", " ", 
         RowBox[{"3420", "*", 
          RowBox[{"Pimu", "^", "3"}]}], " ", "+", " ", 
         RowBox[{"567", "*", 
          RowBox[{"Pimu", "^", "4"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "5"}]}], " ", "-", " ", "\n", "   ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4", " ", "-", " ", 
          RowBox[{"3", "*", "Pimu"}]}], ")"}], "^", "2"}], "*", 
       RowBox[{"(", 
        RowBox[{"64", " ", "-", " ", 
         RowBox[{"96", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"33", "*", 
          RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "6"}]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"J1", "\[Equal]", "J1def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.737791519919961*^9}, {
  3.737792713828249*^9, 3.737792714602293*^9}, {3.7377928997618837`*^9, 
  3.737792925992384*^9}, {3.7377933599892073`*^9, 3.737793383806569*^9}}],

Cell[BoxData[
 RowBox[{"J1", "\[Equal]", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"5", " ", 
     SuperscriptBox["h", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "h"}], "+", "H"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", "H"}], "+", 
        RowBox[{"h", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", 
           RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], "4"]}]], 
   RowBox[{"6", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"384", " ", 
       SuperscriptBox["H", "6"], " ", "Pimu"}], "+", 
      RowBox[{"32", " ", "h", " ", 
       SuperscriptBox["H", "5"], " ", 
       RowBox[{"(", 
        RowBox[{"32", "-", 
         RowBox[{"78", " ", "Pimu"}], "+", 
         RowBox[{"27", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["h", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"4", "-", 
          RowBox[{"3", " ", "Pimu"}]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"64", "-", 
         RowBox[{"96", " ", "Pimu"}], "+", 
         RowBox[{"33", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["h", "2"], " ", 
       SuperscriptBox["H", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "640"}], "+", 
         RowBox[{"1236", " ", "Pimu"}], "-", 
         RowBox[{"654", " ", 
          SuperscriptBox["Pimu", "2"]}], "+", 
         RowBox[{"81", " ", 
          SuperscriptBox["Pimu", "3"]}]}], ")"}]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["h", "3"], " ", 
       SuperscriptBox["H", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1280"}], "+", 
         RowBox[{"2772", " ", "Pimu"}], "-", 
         RowBox[{"1965", " ", 
          SuperscriptBox["Pimu", "2"]}], "+", 
         RowBox[{"459", " ", 
          SuperscriptBox["Pimu", "3"]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["h", "4"], " ", 
       SuperscriptBox["H", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"5120", "-", 
         RowBox[{"12912", " ", "Pimu"}], "+", 
         RowBox[{"11472", " ", 
          SuperscriptBox["Pimu", "2"]}], "-", 
         RowBox[{"4050", " ", 
          SuperscriptBox["Pimu", "3"]}], "+", 
         RowBox[{"405", " ", 
          SuperscriptBox["Pimu", "4"]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["h", "5"], " ", "H", " ", 
       RowBox[{"(", 
        RowBox[{"2560", "-", 
         RowBox[{"7248", " ", "Pimu"}], "+", 
         RowBox[{"7548", " ", 
          SuperscriptBox["Pimu", "2"]}], "-", 
         RowBox[{"3420", " ", 
          SuperscriptBox["Pimu", "3"]}], "+", 
         RowBox[{"567", " ", 
          SuperscriptBox["Pimu", "4"]}]}], ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.737792937131021*^9, 3.737793248456828*^9, 
  3.737793282531777*^9, 3.7377934447500553`*^9, 3.7377935699312153`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"J2def", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"5", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"H", " ", "-", " ", "h"}], ")"}], "^", "4"}], "*", "h", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", "*", "H"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], " ", "+", " ", 
              RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
         "4"}]}], ")"}]}], ")"}], "*", "6", "*", "Pimu", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "48"}], "*", 
       RowBox[{"H", "^", "6"}], "*", 
       RowBox[{"(", 
        RowBox[{"4", " ", "-", " ", 
         RowBox[{"6", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"3", "*", 
          RowBox[{"Pimu", "^", "2"}]}]}], ")"}]}], " ", "+", " ", 
      RowBox[{"8", "*", 
       RowBox[{"H", "^", "5"}], "*", 
       RowBox[{"(", 
        RowBox[{"160", " ", "-", " ", 
         RowBox[{"312", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"117", "*", 
          RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", "h"}], " ", "+", " ", 
      RowBox[{"4", "*", 
       RowBox[{"H", "^", "4"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "592"}], " ", "+", " ", 
         RowBox[{"1500", "*", "Pimu"}], " ", "-", " ", 
         RowBox[{"810", "*", 
          RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
         RowBox[{"45", "*", 
          RowBox[{"Pimu", "^", "3"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "2"}]}], " ", "+", " ", "\n", "   ", 
      RowBox[{
       RowBox[{"H", "^", "3"}], "*", 
       RowBox[{"(", 
        RowBox[{"512", " ", "-", " ", 
         RowBox[{"3552", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"3372", "*", 
          RowBox[{"Pimu", "^", "2"}]}], " ", "-", " ", 
         RowBox[{"711", "*", 
          RowBox[{"Pimu", "^", "3"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "3"}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"H", "^", "2"}], "*", 
       RowBox[{"(", 
        RowBox[{"2752", " ", "-", " ", 
         RowBox[{"4896", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"2700", "*", 
          RowBox[{"Pimu", "^", "2"}]}], " ", "-", " ", 
         RowBox[{"441", "*", 
          RowBox[{"Pimu", "^", "3"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "4"}]}], " ", "+", " ", 
      RowBox[{"H", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2816"}], " ", "+", " ", 
         RowBox[{"7200", "*", "Pimu"}], " ", "-", " ", 
         RowBox[{"6516", "*", 
          RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
         RowBox[{"2385", "*", 
          RowBox[{"Pimu", "^", "3"}]}], " ", "-", " ", 
         RowBox[{"270", "*", 
          RowBox[{"Pimu", "^", "4"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "5"}]}], " ", "+", " ", "\n", "   ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4", " ", "-", " ", 
          RowBox[{"3", "*", "Pimu"}]}], ")"}], "^", "2"}], "*", 
       RowBox[{"(", 
        RowBox[{"52", " ", "-", " ", 
         RowBox[{"81", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"30", "*", 
          RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "6"}]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"J2", "\[Equal]", "J2def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.737791519919961*^9}, {
  3.737792713828249*^9, 3.737792714602293*^9}, {3.7377928997618837`*^9, 
  3.737792915281771*^9}, {3.737793360005208*^9, 3.737793383828571*^9}}],

Cell[BoxData[
 RowBox[{"J2", "\[Equal]", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"5", " ", "h", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "h"}], "+", "H"}], ")"}], "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", "H"}], "+", 
        RowBox[{"h", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", 
           RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], "4"]}]], 
   RowBox[{"6", " ", "Pimu", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "48"}], " ", 
       SuperscriptBox["H", "6"], " ", 
       RowBox[{"(", 
        RowBox[{"4", "-", 
         RowBox[{"6", " ", "Pimu"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"4", "-", 
          RowBox[{"3", " ", "Pimu"}]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"52", "-", 
         RowBox[{"81", " ", "Pimu"}], "+", 
         RowBox[{"30", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "+", 
      RowBox[{"8", " ", "h", " ", 
       SuperscriptBox["H", "5"], " ", 
       RowBox[{"(", 
        RowBox[{"160", "-", 
         RowBox[{"312", " ", "Pimu"}], "+", 
         RowBox[{"117", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "3"], " ", 
       SuperscriptBox["H", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"512", "-", 
         RowBox[{"3552", " ", "Pimu"}], "+", 
         RowBox[{"3372", " ", 
          SuperscriptBox["Pimu", "2"]}], "-", 
         RowBox[{"711", " ", 
          SuperscriptBox["Pimu", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "4"], " ", 
       SuperscriptBox["H", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"2752", "-", 
         RowBox[{"4896", " ", "Pimu"}], "+", 
         RowBox[{"2700", " ", 
          SuperscriptBox["Pimu", "2"]}], "-", 
         RowBox[{"441", " ", 
          SuperscriptBox["Pimu", "3"]}]}], ")"}]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["h", "2"], " ", 
       SuperscriptBox["H", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "592"}], "+", 
         RowBox[{"1500", " ", "Pimu"}], "-", 
         RowBox[{"810", " ", 
          SuperscriptBox["Pimu", "2"]}], "+", 
         RowBox[{"45", " ", 
          SuperscriptBox["Pimu", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "5"], " ", "H", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2816"}], "+", 
         RowBox[{"7200", " ", "Pimu"}], "-", 
         RowBox[{"6516", " ", 
          SuperscriptBox["Pimu", "2"]}], "+", 
         RowBox[{"2385", " ", 
          SuperscriptBox["Pimu", "3"]}], "-", 
         RowBox[{"270", " ", 
          SuperscriptBox["Pimu", "4"]}]}], ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.73779293903813*^9, 3.7377932489408555`*^9, 
  3.73779328258778*^9, 3.7377934447690563`*^9, 3.7377935699502163`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["K1 and K2", "Subsection",
 CellChangeTimes->{{3.737791727462832*^9, 3.737791730118984*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"K1def", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"12", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"48", "*", 
         RowBox[{"H", "^", "5"}], "*", "Pimu"}], " ", "+", " ", 
        RowBox[{"24", "*", 
         RowBox[{"H", "^", "4"}], "*", 
         RowBox[{"(", 
          RowBox[{"6", " ", "-", " ", 
           RowBox[{"11", "*", "Pimu"}], " ", "+", " ", 
           RowBox[{"3", "*", 
            RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", "h"}], " ", "-", " ", 
        RowBox[{"6", "*", 
         RowBox[{"H", "^", "3"}], "*", 
         RowBox[{"(", 
          RowBox[{"96", " ", "-", " ", 
           RowBox[{"166", "*", "Pimu"}], " ", "+", " ", 
           RowBox[{"61", "*", 
            RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "2"}]}], " ", "+", " ", 
        RowBox[{"2", "*", 
         RowBox[{"H", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{"432", " ", "-", " ", 
           RowBox[{"878", "*", "Pimu"}], " ", "+", " ", 
           RowBox[{"471", "*", 
            RowBox[{"Pimu", "^", "2"}]}], " ", "-", " ", 
           RowBox[{"45", "*", 
            RowBox[{"Pimu", "^", "3"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "3"}]}], " ", "+", " ", 
        RowBox[{"H", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "576"}], " ", "+", " ", 
           RowBox[{"1340", "*", "Pimu"}], " ", "-", " ", 
           RowBox[{"960", "*", 
            RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
           RowBox[{"207", "*", 
            RowBox[{"Pimu", "^", "3"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "4"}]}], " ", "+", " ", "\n", "    ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"144", " ", "-", " ", 
           RowBox[{"364", "*", "Pimu"}], " ", "+", " ", 
           RowBox[{"300", "*", 
            RowBox[{"Pimu", "^", "2"}]}], " ", "-", " ", 
           RowBox[{"81", "*", 
            RowBox[{"Pimu", "^", "3"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "5"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"5", "*", 
      RowBox[{"h", "^", "3"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "H"}], " ", "+", " ", "h"}], ")"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", "*", "H"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], " ", "+", " ", 
            RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
       "3"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"K1", "\[Equal]", "K1def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.7377915277214074`*^9}, {
  3.7377927154173393`*^9, 3.737792716264388*^9}, {3.737792945228484*^9, 
  3.737792971324977*^9}, {3.737793360019209*^9, 3.737793383846572*^9}}],

Cell[BoxData[
 RowBox[{"K1", "\[Equal]", 
  FractionBox[
   RowBox[{"12", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"48", " ", 
       SuperscriptBox["H", "5"], " ", "Pimu"}], "+", 
      RowBox[{"24", " ", "h", " ", 
       SuperscriptBox["H", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"6", "-", 
         RowBox[{"11", " ", "Pimu"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["h", "2"], " ", 
       SuperscriptBox["H", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"96", "-", 
         RowBox[{"166", " ", "Pimu"}], "+", 
         RowBox[{"61", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "5"], " ", 
       RowBox[{"(", 
        RowBox[{"144", "-", 
         RowBox[{"364", " ", "Pimu"}], "+", 
         RowBox[{"300", " ", 
          SuperscriptBox["Pimu", "2"]}], "-", 
         RowBox[{"81", " ", 
          SuperscriptBox["Pimu", "3"]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["h", "3"], " ", 
       SuperscriptBox["H", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"432", "-", 
         RowBox[{"878", " ", "Pimu"}], "+", 
         RowBox[{"471", " ", 
          SuperscriptBox["Pimu", "2"]}], "-", 
         RowBox[{"45", " ", 
          SuperscriptBox["Pimu", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "4"], " ", "H", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "576"}], "+", 
         RowBox[{"1340", " ", "Pimu"}], "-", 
         RowBox[{"960", " ", 
          SuperscriptBox["Pimu", "2"]}], "+", 
         RowBox[{"207", " ", 
          SuperscriptBox["Pimu", "3"]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"5", " ", 
    SuperscriptBox["h", "3"], " ", 
    RowBox[{"(", 
     RowBox[{"h", "-", "H"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "H"}], "+", 
       RowBox[{"h", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", 
          RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], "3"]}]]}]], "Output",
 CellChangeTimes->{3.7377929837666883`*^9, 3.737793248999859*^9, 
  3.7377932826057816`*^9, 3.7377934447860575`*^9, 3.737793569966217*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"K2def", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"5", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"H", " ", "-", " ", "h"}], ")"}], "^", "3"}], "*", "h", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", "*", "H"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], " ", "+", " ", 
              RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
         "3"}]}], ")"}]}], ")"}], "*", "12", "*", "Pimu", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"24", "*", 
       RowBox[{"H", "^", "5"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], " ", "+", " ", "Pimu"}], ")"}]}], " ", "+", " ", 
      RowBox[{"12", "*", 
       RowBox[{"H", "^", "4"}], "*", 
       RowBox[{"(", 
        RowBox[{"34", " ", "-", " ", 
         RowBox[{"21", "*", "Pimu"}]}], ")"}], "*", "h"}], " ", "-", " ", 
      RowBox[{"3", "*", 
       RowBox[{"H", "^", "3"}], "*", 
       RowBox[{"(", 
        RowBox[{"192", " ", "-", " ", 
         RowBox[{"170", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"25", "*", 
          RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "2"}]}], " ", "+", " ", 
      RowBox[{"3", "*", 
       RowBox[{"H", "^", "2"}], "*", 
       RowBox[{"(", 
        RowBox[{"80", " ", "-", " ", 
         RowBox[{"62", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"3", "*", 
          RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "3"}]}], " ", "+", " ", "\n", "   ", 
      RowBox[{"H", "*", 
       RowBox[{"(", 
        RowBox[{"96", " ", "-", " ", 
         RowBox[{"286", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"222", "*", 
          RowBox[{"Pimu", "^", "2"}]}], " ", "-", " ", 
         RowBox[{"45", "*", 
          RowBox[{"Pimu", "^", "3"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "4"}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "72"}], " ", "+", " ", 
         RowBox[{"190", "*", "Pimu"}], " ", "-", " ", 
         RowBox[{"162", "*", 
          RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
         RowBox[{"45", "*", 
          RowBox[{"Pimu", "^", "3"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "5"}]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"K2", "\[Equal]", "K2def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.7377915277214074`*^9}, {
  3.7377927154173393`*^9, 3.737792716264388*^9}, {3.737792945228484*^9, 
  3.7377929614524117`*^9}, {3.7377933600322094`*^9, 3.737793383865573*^9}}],

Cell[BoxData[
 RowBox[{"K2", "\[Equal]", 
  FractionBox[
   RowBox[{"12", " ", "Pimu", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"12", " ", "h", " ", 
       SuperscriptBox["H", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"34", "-", 
         RowBox[{"21", " ", "Pimu"}]}], ")"}]}], "+", 
      RowBox[{"24", " ", 
       SuperscriptBox["H", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", "Pimu"}], ")"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["h", "3"], " ", 
       SuperscriptBox["H", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"80", "-", 
         RowBox[{"62", " ", "Pimu"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["h", "2"], " ", 
       SuperscriptBox["H", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"192", "-", 
         RowBox[{"170", " ", "Pimu"}], "+", 
         RowBox[{"25", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "4"], " ", "H", " ", 
       RowBox[{"(", 
        RowBox[{"96", "-", 
         RowBox[{"286", " ", "Pimu"}], "+", 
         RowBox[{"222", " ", 
          SuperscriptBox["Pimu", "2"]}], "-", 
         RowBox[{"45", " ", 
          SuperscriptBox["Pimu", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "72"}], "+", 
         RowBox[{"190", " ", "Pimu"}], "-", 
         RowBox[{"162", " ", 
          SuperscriptBox["Pimu", "2"]}], "+", 
         RowBox[{"45", " ", 
          SuperscriptBox["Pimu", "3"]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"5", " ", "h", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "h"}], "+", "H"}], ")"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "H"}], "+", 
       RowBox[{"h", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", 
          RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], "3"]}]]}]], "Output",
 CellChangeTimes->{{3.7377929631875114`*^9, 3.737792986436841*^9}, 
   3.73779324901886*^9, 3.7377932826227818`*^9, 3.737793444802058*^9, 
   3.737793569983218*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["L1 and L2", "Subsection",
 CellChangeTimes->{{3.73779174753498*^9, 3.737791749335083*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"L1def", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"5", "*", 
          RowBox[{"(", 
           RowBox[{"H", " ", "-", " ", "h"}], ")"}], "*", 
          RowBox[{"h", "^", "3"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", "*", "H"}], " ", "+", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], " ", "+", " ", 
                RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^",
            "3"}]}], ")"}]}], ")"}]}], ")"}], "*", "6", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"48", "*", 
       RowBox[{"H", "^", "5"}], "*", "Pimu"}], " ", "+", " ", 
      RowBox[{"24", "*", 
       RowBox[{"H", "^", "4"}], "*", 
       RowBox[{"(", 
        RowBox[{"16", " ", "-", " ", 
         RowBox[{"21", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"3", "*", 
          RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", "h"}], " ", "-", " ", 
      RowBox[{"6", "*", 
       RowBox[{"H", "^", "3"}], "*", 
       RowBox[{"(", 
        RowBox[{"256", " ", "-", " ", 
         RowBox[{"356", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"91", "*", 
          RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "2"}]}], " ", "+", " ", "\n", "   ", 
      RowBox[{"2", "*", 
       RowBox[{"H", "^", "2"}], "*", 
       RowBox[{"(", 
        RowBox[{"1152", " ", "-", " ", 
         RowBox[{"1928", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"801", "*", 
          RowBox[{"Pimu", "^", "2"}]}], " ", "-", " ", 
         RowBox[{"45", "*", 
          RowBox[{"Pimu", "^", "3"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "3"}]}], " ", "+", " ", 
      RowBox[{"H", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1536"}], " ", "+", " ", 
         RowBox[{"3080", "*", "Pimu"}], " ", "-", " ", 
         RowBox[{"1830", "*", 
          RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
         RowBox[{"297", "*", 
          RowBox[{"Pimu", "^", "3"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "4"}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"384", " ", "-", " ", 
         RowBox[{"904", "*", "Pimu"}], " ", "+", " ", 
         RowBox[{"690", "*", 
          RowBox[{"Pimu", "^", "2"}]}], " ", "-", " ", 
         RowBox[{"171", "*", 
          RowBox[{"Pimu", "^", "3"}]}]}], ")"}], "*", 
       RowBox[{"h", "^", "5"}]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"L1", "\[Equal]", "L1def"}]}], "Input",
 CellChangeTimes->{{3.737793004740888*^9, 3.737793014013418*^9}, {
  3.7377933600442104`*^9, 3.7377933838835735`*^9}}],

Cell[BoxData[
 RowBox[{"L1", "\[Equal]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"6", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"48", " ", 
        SuperscriptBox["H", "5"], " ", "Pimu"}], "+", 
       RowBox[{"24", " ", "h", " ", 
        SuperscriptBox["H", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"16", "-", 
          RowBox[{"21", " ", "Pimu"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["h", "2"], " ", 
        SuperscriptBox["H", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"256", "-", 
          RowBox[{"356", " ", "Pimu"}], "+", 
          RowBox[{"91", " ", 
           SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["h", "5"], " ", 
        RowBox[{"(", 
         RowBox[{"384", "-", 
          RowBox[{"904", " ", "Pimu"}], "+", 
          RowBox[{"690", " ", 
           SuperscriptBox["Pimu", "2"]}], "-", 
          RowBox[{"171", " ", 
           SuperscriptBox["Pimu", "3"]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["h", "3"], " ", 
        SuperscriptBox["H", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1152", "-", 
          RowBox[{"1928", " ", "Pimu"}], "+", 
          RowBox[{"801", " ", 
           SuperscriptBox["Pimu", "2"]}], "-", 
          RowBox[{"45", " ", 
           SuperscriptBox["Pimu", "3"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["h", "4"], " ", "H", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1536"}], "+", 
          RowBox[{"3080", " ", "Pimu"}], "-", 
          RowBox[{"1830", " ", 
           SuperscriptBox["Pimu", "2"]}], "+", 
          RowBox[{"297", " ", 
           SuperscriptBox["Pimu", "3"]}]}], ")"}]}]}], ")"}]}], 
    RowBox[{"5", " ", 
     SuperscriptBox["h", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "h"}], "+", "H"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", "H"}], "+", 
        RowBox[{"h", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", 
           RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], 
      "3"]}]]}]}]], "Output",
 CellChangeTimes->{3.737793016805578*^9, 3.737793249036861*^9, 
  3.737793282641783*^9, 3.737793444817059*^9, 3.737793569998219*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"L2def", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"6", "*", "Pimu", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "24"}], "*", 
         RowBox[{"H", "^", "5"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], " ", "+", " ", "Pimu"}], ")"}]}], " ", "+", 
        " ", 
        RowBox[{"12", "*", 
         RowBox[{"H", "^", "4"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "24"}], " ", "+", " ", 
           RowBox[{"11", "*", "Pimu"}]}], ")"}], "*", "h"}], " ", "+", " ", 
        RowBox[{"3", "*", 
         RowBox[{"H", "^", "3"}], "*", 
         RowBox[{"(", 
          RowBox[{"32", " ", "+", " ", 
           RowBox[{"20", "*", "Pimu"}], " ", "-", " ", 
           RowBox[{"5", "*", 
            RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "2"}]}], " ", "+", " ", 
        RowBox[{"3", "*", 
         RowBox[{"H", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{"160", " ", "-", " ", 
           RowBox[{"288", "*", "Pimu"}], " ", "+", " ", 
           RowBox[{"107", "*", 
            RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "3"}]}], " ", "+", " ", 
        RowBox[{"H", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "576"}], " ", "+", " ", 
           RowBox[{"1156", "*", "Pimu"}], " ", "-", " ", 
           RowBox[{"657", "*", 
            RowBox[{"Pimu", "^", "2"}]}], " ", "+", " ", 
           RowBox[{"90", "*", 
            RowBox[{"Pimu", "^", "3"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "4"}]}], " ", "+", " ", "\n", "    ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"192", " ", "-", " ", 
           RowBox[{"460", "*", "Pimu"}], " ", "+", " ", 
           RowBox[{"357", "*", 
            RowBox[{"Pimu", "^", "2"}]}], " ", "-", " ", 
           RowBox[{"90", "*", 
            RowBox[{"Pimu", "^", "3"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "5"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"5", "*", "h", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "H"}], " ", "+", " ", "h"}], ")"}], "^", "3"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", "*", "H"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], " ", "+", " ", 
            RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
       "3"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"L2", "\[Equal]", "L2def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.737791534131774*^9}, {
  3.7377917519592333`*^9, 3.7377917546983895`*^9}, {3.737792717042433*^9, 
  3.7377927177234716`*^9}, {3.7377929904930735`*^9, 3.7377930223008924`*^9}, {
  3.737793360057211*^9, 3.7377933839045753`*^9}}],

Cell[BoxData[
 RowBox[{"L2", "\[Equal]", 
  FractionBox[
   RowBox[{"6", " ", "Pimu", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "24"}], " ", 
       SuperscriptBox["H", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", "Pimu"}], ")"}]}], "+", 
      RowBox[{"12", " ", "h", " ", 
       SuperscriptBox["H", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "24"}], "+", 
         RowBox[{"11", " ", "Pimu"}]}], ")"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["h", "2"], " ", 
       SuperscriptBox["H", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"32", "+", 
         RowBox[{"20", " ", "Pimu"}], "-", 
         RowBox[{"5", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["h", "3"], " ", 
       SuperscriptBox["H", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"160", "-", 
         RowBox[{"288", " ", "Pimu"}], "+", 
         RowBox[{"107", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "5"], " ", 
       RowBox[{"(", 
        RowBox[{"192", "-", 
         RowBox[{"460", " ", "Pimu"}], "+", 
         RowBox[{"357", " ", 
          SuperscriptBox["Pimu", "2"]}], "-", 
         RowBox[{"90", " ", 
          SuperscriptBox["Pimu", "3"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "4"], " ", "H", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "576"}], "+", 
         RowBox[{"1156", " ", "Pimu"}], "-", 
         RowBox[{"657", " ", 
          SuperscriptBox["Pimu", "2"]}], "+", 
         RowBox[{"90", " ", 
          SuperscriptBox["Pimu", "3"]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"5", " ", "h", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"h", "-", "H"}], ")"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "H"}], "+", 
       RowBox[{"h", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", 
          RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], "3"]}]]}]], "Output",
 CellChangeTimes->{3.737793022642912*^9, 3.737793249092864*^9, 
  3.7377932826597843`*^9, 3.7377934448340597`*^9, 3.73779357001422*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["M1 and M2", "Subsection",
 CellChangeTimes->{{3.7377917629588623`*^9, 3.737791764246936*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M1def", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"18", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", "*", 
         RowBox[{"H", "^", "4"}], "*", "Pimu"}], " ", "-", " ", 
        RowBox[{"4", "*", 
         RowBox[{"H", "^", "3"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "6"}], " ", "+", " ", 
           RowBox[{"5", "*", "Pimu"}]}], ")"}], "*", "h"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"H", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "72"}], " ", "+", " ", 
           RowBox[{"60", "*", "Pimu"}], " ", "-", " ", 
           RowBox[{"5", "*", 
            RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "2"}]}], " ", "+", " ", 
        RowBox[{"8", "*", "H", "*", 
         RowBox[{"(", 
          RowBox[{"9", " ", "-", " ", 
           RowBox[{"10", "*", "Pimu"}], " ", "+", " ", 
           RowBox[{"2", "*", 
            RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "3"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "24"}], " ", "+", " ", 
           RowBox[{"36", "*", "Pimu"}], " ", "-", " ", 
           RowBox[{"13", "*", 
            RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "4"}]}]}], ")"}]}], ")"}], "/", "\n", "  ", 
    RowBox[{"(", 
     RowBox[{"5", "*", 
      RowBox[{"(", 
       RowBox[{"H", " ", "-", " ", "h"}], ")"}], "*", 
      RowBox[{"h", "^", "2"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", "*", "H"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], " ", "+", " ", 
            RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
       "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"M1", "\[Equal]", "M1def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.7377915391540613`*^9}, {
  3.737792718445513*^9, 3.737792719072549*^9}, {3.737793028794264*^9, 
  3.737793046224261*^9}, {3.7377933600692115`*^9, 3.737793383920576*^9}}],

Cell[BoxData[
 RowBox[{"M1", "\[Equal]", 
  FractionBox[
   RowBox[{"18", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["H", "4"], " ", "Pimu"}], "-", 
      RowBox[{"4", " ", "h", " ", 
       SuperscriptBox["H", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "6"}], "+", 
         RowBox[{"5", " ", "Pimu"}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "24"}], "+", 
         RowBox[{"36", " ", "Pimu"}], "-", 
         RowBox[{"13", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "2"], " ", 
       SuperscriptBox["H", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "72"}], "+", 
         RowBox[{"60", " ", "Pimu"}], "-", 
         RowBox[{"5", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["h", "3"], " ", "H", " ", 
       RowBox[{"(", 
        RowBox[{"9", "-", 
         RowBox[{"10", " ", "Pimu"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"5", " ", 
    SuperscriptBox["h", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "h"}], "+", "H"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "H"}], "+", 
       RowBox[{"h", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", 
          RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], "2"]}]]}]], "Output",
 CellChangeTimes->{3.7377930469533024`*^9, 3.737793249140867*^9, 
  3.737793282675785*^9, 3.7377934448500605`*^9, 3.737793570028221*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M2def", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"6", "*", "Pimu", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"12", "*", 
         RowBox[{"H", "^", "4"}]}], " ", "+", " ", 
        RowBox[{"5", "*", 
         RowBox[{"H", "^", "3"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "16"}], " ", "+", " ", 
           RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}], " ", "-", " ", 
        RowBox[{"15", "*", 
         RowBox[{"H", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "12"}], " ", "+", " ", 
           RowBox[{"7", "*", "Pimu"}]}], ")"}], "*", 
         RowBox[{"h", "^", "2"}]}], " ", "-", " ", 
        RowBox[{"3", "*", "H", "*", 
         RowBox[{"(", 
          RowBox[{"56", " ", "-", " ", 
           RowBox[{"57", "*", "Pimu"}], " ", "+", " ", 
           RowBox[{"10", "*", 
            RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "3"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"56", " ", "-", " ", 
           RowBox[{"83", "*", "Pimu"}], " ", "+", " ", 
           RowBox[{"30", "*", 
            RowBox[{"Pimu", "^", "2"}]}]}], ")"}], "*", 
         RowBox[{"h", "^", "4"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"5", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"H", " ", "-", " ", "h"}], ")"}], "^", "2"}], "*", "h", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", "*", "H"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], " ", "+", " ", 
            RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}], "^", 
       "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"M2", "\[Equal]", "M2def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
  3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
  3.737791293454008*^9}, {3.7377914921943755`*^9, 3.7377915391540613`*^9}, {
  3.737792718445513*^9, 3.737792719072549*^9}, {3.737793028794264*^9, 
  3.7377930556838017`*^9}, {3.737793360079212*^9, 3.737793383936577*^9}}],

Cell[BoxData[
 RowBox[{"M2", "\[Equal]", 
  FractionBox[
   RowBox[{"6", " ", "Pimu", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"12", " ", 
       SuperscriptBox["H", "4"]}], "+", 
      RowBox[{"5", " ", "h", " ", 
       SuperscriptBox["H", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "16"}], "+", 
         RowBox[{"3", " ", "Pimu"}]}], ")"}]}], "-", 
      RowBox[{"15", " ", 
       SuperscriptBox["h", "2"], " ", 
       SuperscriptBox["H", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "12"}], "+", 
         RowBox[{"7", " ", "Pimu"}]}], ")"}]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["h", "3"], " ", "H", " ", 
       RowBox[{"(", 
        RowBox[{"56", "-", 
         RowBox[{"57", " ", "Pimu"}], "+", 
         RowBox[{"10", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["h", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"56", "-", 
         RowBox[{"83", " ", "Pimu"}], "+", 
         RowBox[{"30", " ", 
          SuperscriptBox["Pimu", "2"]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"5", " ", "h", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "h"}], "+", "H"}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "H"}], "+", 
       RowBox[{"h", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", 
          RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}], "2"]}]]}]], "Output",
 CellChangeTimes->{3.737793056287836*^9, 3.737793249157868*^9, 
  3.737793282691786*^9, 3.7377934448660617`*^9, 3.7377935700422215`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(C11-Pimu*C12) and (C21-Pimu*C22)", "Subsection",
 CellChangeTimes->{{3.737791771279338*^9, 3.7377917854951515`*^9}, {
  3.737792332798455*^9, 3.7377923736947947`*^9}, {3.737793542654655*^9, 
  3.737793545926842*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"C1def", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"6", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"H", "^", "2"}]}], " ", "+", " ", 
        RowBox[{"2", "*", "H", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "+", " ", 
           RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", " ", "-", " ", 
           RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", 
         RowBox[{"h", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"h", "^", "3"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "H"}], " ", "+", " ", "h"}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", "*", "H"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], " ", "+", " ", 
           RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}]}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C11", "-", 
    RowBox[{"Pimu", "*", "C12"}]}], ")"}], "\[Equal]", "C1def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
   3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
   3.737791293454008*^9}, {3.7377914921943755`*^9, 3.7377915391540613`*^9}, {
   3.737792378723082*^9, 3.7377923830903316`*^9}, {3.7377927235928073`*^9, 
   3.7377927241878414`*^9}, {3.737793065919387*^9, 3.7377930975161943`*^9}, {
   3.737793360089213*^9, 3.737793383948578*^9}, 3.73779355497636*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"C11", "-", 
   RowBox[{"C12", " ", "Pimu"}]}], "\[Equal]", 
  FractionBox[
   RowBox[{"6", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["H", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["h", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"2", "-", 
         RowBox[{"3", " ", "Pimu"}]}], ")"}]}], "+", 
      RowBox[{"2", " ", "h", " ", "H", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["h", "3"], " ", 
    RowBox[{"(", 
     RowBox[{"h", "-", "H"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", "H"}], "+", 
      RowBox[{"h", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", 
         RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.73779309795922*^9, 3.737793249170869*^9, 3.737793282706787*^9, 
   3.7377934448810625`*^9, {3.7377935557784057`*^9, 3.7377935700572224`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"C2def", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"6", "*", "Pimu", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", "*", "H"}], " ", "-", " ", "h"}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"H", " ", "-", " ", "h"}], ")"}], "^", "2"}], "*", "h", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", "*", "H"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], " ", "+", " ", 
           RowBox[{"3", "*", "Pimu"}]}], ")"}], "*", "h"}]}], ")"}]}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C21", "-", 
    RowBox[{"Pimu", "*", "C22"}]}], ")"}], "\[Equal]", "C2def"}]}], "Input",
 CellChangeTimes->{{3.7377907861199903`*^9, 3.7377910976958113`*^9}, {
   3.7377911391151805`*^9, 3.7377912199268026`*^9}, {3.7377912595640697`*^9, 
   3.737791293454008*^9}, {3.7377914921943755`*^9, 3.7377915391540613`*^9}, {
   3.737792378723082*^9, 3.7377923830903316`*^9}, {3.7377927235928073`*^9, 
   3.7377927241878414`*^9}, {3.737793065919387*^9, 3.7377930682425203`*^9}, {
   3.7377931077087774`*^9, 3.7377931155052233`*^9}, {3.7377933600972133`*^9, 
   3.737793383958578*^9}, 3.737793560181658*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"C21", "-", 
   RowBox[{"C22", " ", "Pimu"}]}], "\[Equal]", 
  FractionBox[
   RowBox[{"6", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "h"}], "+", 
      RowBox[{"3", " ", "H"}]}], ")"}], " ", "Pimu"}], 
   RowBox[{"h", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "h"}], "+", "H"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", "H"}], "+", 
      RowBox[{"h", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", 
         RowBox[{"3", " ", "Pimu"}]}], ")"}]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.7377931158732443`*^9, 3.73779324918487*^9, 3.7377932827187877`*^9, 
   3.7377934448950634`*^9, {3.737793560554679*^9, 3.7377935700672226`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1680, 950},
WindowMargins->{{-9, Automatic}, {Automatic, -9}},
Magnification:>0.9 Inherited,
FrontEndVersion->"10.0 for Microsoft Windows (64-bit) (December 4, 2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 101, 1, 61, "Section"],
Cell[CellGroupData[{
Cell[706, 27, 612, 10, 50, "Input"],
Cell[1321, 39, 773, 12, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2143, 57, 114, 1, 61, "Section"],
Cell[CellGroupData[{
Cell[2282, 62, 244, 5, 50, "Input"],
Cell[2529, 69, 184, 4, 42, "Output"],
Cell[2716, 75, 179, 4, 42, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2944, 85, 247, 3, 61, "Section"],
Cell[CellGroupData[{
Cell[3216, 92, 99, 1, 45, "Subsection"],
Cell[CellGroupData[{
Cell[3340, 97, 2763, 69, 70, "Input"],
Cell[6106, 168, 2029, 60, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8172, 233, 2749, 71, 70, "Input"],
Cell[10924, 306, 2153, 65, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13126, 377, 112, 1, 45, "Subsection"],
Cell[CellGroupData[{
Cell[13263, 382, 3803, 90, 90, "Input"],
Cell[17069, 474, 2905, 82, 69, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20011, 561, 3911, 99, 110, "Input"],
Cell[23925, 662, 3140, 92, 69, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27102, 759, 4206, 101, 110, "Input"],
Cell[31311, 862, 3285, 93, 69, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34633, 960, 4003, 100, 90, "Input"],
Cell[38639, 1062, 3161, 91, 69, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[41849, 1159, 166, 2, 45, "Subsection"],
Cell[CellGroupData[{
Cell[42040, 1165, 5165, 129, 130, "Input"],
Cell[47208, 1296, 4194, 123, 91, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51439, 1424, 6098, 144, 110, "Input"],
Cell[57540, 1570, 4859, 134, 91, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62436, 1709, 5526, 131, 150, "Input"],
Cell[67965, 1842, 4385, 121, 110, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[72399, 1969, 148, 2, 45, "Subsection"],
Cell[CellGroupData[{
Cell[72572, 1975, 3708, 93, 90, "Input"],
Cell[76283, 2070, 3043, 87, 69, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79363, 2162, 3806, 97, 90, "Input"],
Cell[83172, 2261, 3134, 91, 69, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[86355, 2358, 97, 1, 45, "Subsection"],
Cell[CellGroupData[{
Cell[86477, 2363, 3014, 75, 90, "Input"],
Cell[89494, 2440, 2291, 66, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91822, 2511, 2869, 73, 70, "Input"],
Cell[94694, 2586, 2280, 67, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[97023, 2659, 96, 1, 45, "Subsection"],
Cell[CellGroupData[{
Cell[97144, 2664, 2768, 73, 70, "Input"],
Cell[99915, 2739, 2402, 69, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[102354, 2813, 3066, 78, 70, "Input"],
Cell[105423, 2893, 2279, 67, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[107751, 2966, 99, 1, 45, "Subsection"],
Cell[CellGroupData[{
Cell[107875, 2971, 2343, 60, 70, "Input"],
Cell[110221, 3033, 1757, 53, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112015, 3091, 2231, 57, 50, "Input"],
Cell[114249, 3150, 1673, 50, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[115971, 3206, 223, 3, 45, "Subsection"],
Cell[CellGroupData[{
Cell[116219, 3213, 1669, 44, 50, "Input"],
Cell[117891, 3259, 1078, 34, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119006, 3298, 1320, 33, 50, "Input"],
Cell[120329, 3333, 793, 25, 46, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
